Class: UltracartClient::ConversationVirtualAgentCapabilities

Inherits:
Object
  • Object
show all
Defined in:
lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ConversationVirtualAgentCapabilities

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 151

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `UltracartClient::ConversationVirtualAgentCapabilities` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `UltracartClient::ConversationVirtualAgentCapabilities`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_custom_collections')
    self.access_custom_collections = attributes[:'access_custom_collections']
  end

  if attributes.key?(:'access_storefront_and_item')
    self.access_storefront_and_item = attributes[:'access_storefront_and_item']
  end

  if attributes.key?(:'cancel_subscription')
    self.cancel_subscription = attributes[:'cancel_subscription']
  end

  if attributes.key?(:'custom_collection_oids')
    if (value = attributes[:'custom_collection_oids']).is_a?(Array)
      self.custom_collection_oids = value
    end
  end

  if attributes.key?(:'custom_collections')
    if (value = attributes[:'custom_collections']).is_a?(Array)
      self.custom_collections = value
    end
  end

  if attributes.key?(:'delay_subscription')
    self.delay_subscription = attributes[:'delay_subscription']
  end

  if attributes.key?(:'generate_coupon')
    self.generate_coupon = attributes[:'generate_coupon']
  end

  if attributes.key?(:'lookup_order_information')
    self.lookup_order_information = attributes[:'lookup_order_information']
  end

  if attributes.key?(:'lookup_subscription_information')
    self.lookup_subscription_information = attributes[:'lookup_subscription_information']
  end

  if attributes.key?(:'open_support_ticket')
    self.open_support_ticket = attributes[:'open_support_ticket']
  end

  if attributes.key?(:'open_support_ticket_channel')
    self.open_support_ticket_channel = attributes[:'open_support_ticket_channel']
  end

  if attributes.key?(:'open_support_ticket_channel_email')
    self.open_support_ticket_channel_email = attributes[:'open_support_ticket_channel_email']
  end

  if attributes.key?(:'open_support_ticket_zoho_desk_department_id')
    self.open_support_ticket_zoho_desk_department_id = attributes[:'open_support_ticket_zoho_desk_department_id']
  end

  if attributes.key?(:'pause_subscription')
    self.pause_subscription = attributes[:'pause_subscription']
  end

  if attributes.key?(:'resume_subscription')
    self.resume_subscription = attributes[:'resume_subscription']
  end

  if attributes.key?(:'transfer_chat_to_live_agent')
    self.transfer_chat_to_live_agent = attributes[:'transfer_chat_to_live_agent']
  end

  if attributes.key?(:'update_subscription_credit_card')
    self.update_subscription_credit_card = attributes[:'update_subscription_credit_card']
  end

  if attributes.key?(:'zoho_desk_available')
    self.zoho_desk_available = attributes[:'zoho_desk_available']
  end

  if attributes.key?(:'zoho_desk_departments')
    if (value = attributes[:'zoho_desk_departments']).is_a?(Array)
      self.zoho_desk_departments = value
    end
  end
end

Instance Attribute Details

#access_custom_collections ⇒ Object

Permission flag to allow this Agent to search the merchant's custom Typesense collections.



19
20
21
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 19

def access_custom_collections
  @access_custom_collections
end

#access_storefront_and_item ⇒ Object

Permission flag to allow this Agent access to the storefront and item information.



22
23
24
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 22

def access_storefront_and_item
  @access_storefront_and_item
end

#cancel_subscription ⇒ Object

Returns the value of attribute cancel_subscription.



24
25
26
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 24

def cancel_subscription
  @cancel_subscription
end

#custom_collection_oids ⇒ Object

The custom collections this Agent is allowed to search. Empty means none, even when access_custom_collections is true.



27
28
29
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 27

def custom_collection_oids
  @custom_collection_oids
end

#custom_collections ⇒ Object

Read only. All of the merchant's custom collections, to populate the selection list for custom_collection_oids. Changes here are ignored.



30
31
32
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 30

def custom_collections
  @custom_collections
end

#delay_subscription ⇒ Object

Returns the value of attribute delay_subscription.



32
33
34
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 32

def delay_subscription
  @delay_subscription
end

#generate_coupon ⇒ Object

Permission flag to allow this Agent to generate coupons based upon the agent prompt instructions



35
36
37
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 35

def generate_coupon
  @generate_coupon
end

#lookup_order_information ⇒ Object

Returns the value of attribute lookup_order_information.



37
38
39
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 37

def lookup_order_information
  @lookup_order_information
end

#lookup_subscription_information ⇒ Object

Returns the value of attribute lookup_subscription_information.



39
40
41
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 39

def lookup_subscription_information
  @lookup_subscription_information
end

#open_support_ticket ⇒ Object

Returns the value of attribute open_support_ticket.



41
42
43
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 41

def open_support_ticket
  @open_support_ticket
end

#open_support_ticket_channel ⇒ Object

Channel to use to open the support ticket



44
45
46
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 44

def open_support_ticket_channel
  @open_support_ticket_channel
end

#open_support_ticket_channel_email ⇒ Object

Email to send support ticket to



47
48
49
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 47

def open_support_ticket_channel_email
  @open_support_ticket_channel_email
end

#open_support_ticket_zoho_desk_department_id ⇒ Object

Department ID to open a Zoho Desk ticket for



50
51
52
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 50

def open_support_ticket_zoho_desk_department_id
  @open_support_ticket_zoho_desk_department_id
end

#pause_subscription ⇒ Object

Returns the value of attribute pause_subscription.



52
53
54
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 52

def pause_subscription
  @pause_subscription
end

#resume_subscription ⇒ Object

Returns the value of attribute resume_subscription.



54
55
56
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 54

def resume_subscription
  @resume_subscription
end

#transfer_chat_to_live_agent ⇒ Object

Returns the value of attribute transfer_chat_to_live_agent.



56
57
58
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 56

def transfer_chat_to_live_agent
  @transfer_chat_to_live_agent
end

#update_subscription_credit_card ⇒ Object

Returns the value of attribute update_subscription_credit_card.



58
59
60
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 58

def update_subscription_credit_card
  @update_subscription_credit_card
end

#zoho_desk_available ⇒ Object

True if Zoho Desk is connected to UltraCart



61
62
63
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 61

def zoho_desk_available
  @zoho_desk_available
end

#zoho_desk_departments ⇒ Object

Array of Zoho Desk Department if zoho desk is connected to UltraCart



64
65
66
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 64

def zoho_desk_departments
  @zoho_desk_departments
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



114
115
116
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 114

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 89

def self.attribute_map
  {
    :'access_custom_collections' => :'access_custom_collections',
    :'access_storefront_and_item' => :'access_storefront_and_item',
    :'cancel_subscription' => :'cancel_subscription',
    :'custom_collection_oids' => :'custom_collection_oids',
    :'custom_collections' => :'custom_collections',
    :'delay_subscription' => :'delay_subscription',
    :'generate_coupon' => :'generate_coupon',
    :'lookup_order_information' => :'lookup_order_information',
    :'lookup_subscription_information' => :'lookup_subscription_information',
    :'open_support_ticket' => :'open_support_ticket',
    :'open_support_ticket_channel' => :'open_support_ticket_channel',
    :'open_support_ticket_channel_email' => :'open_support_ticket_channel_email',
    :'open_support_ticket_zoho_desk_department_id' => :'open_support_ticket_zoho_desk_department_id',
    :'pause_subscription' => :'pause_subscription',
    :'resume_subscription' => :'resume_subscription',
    :'transfer_chat_to_live_agent' => :'transfer_chat_to_live_agent',
    :'update_subscription_credit_card' => :'update_subscription_credit_card',
    :'zoho_desk_available' => :'zoho_desk_available',
    :'zoho_desk_departments' => :'zoho_desk_departments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



313
314
315
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 313

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



144
145
146
147
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 144

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 119

def self.openapi_types
  {
    :'access_custom_collections' => :'Boolean',
    :'access_storefront_and_item' => :'Boolean',
    :'cancel_subscription' => :'Boolean',
    :'custom_collection_oids' => :'Array<Integer>',
    :'custom_collections' => :'Array<ConversationVirtualAgentCapabilityCustomCollection>',
    :'delay_subscription' => :'Boolean',
    :'generate_coupon' => :'Boolean',
    :'lookup_order_information' => :'Boolean',
    :'lookup_subscription_information' => :'Boolean',
    :'open_support_ticket' => :'Boolean',
    :'open_support_ticket_channel' => :'String',
    :'open_support_ticket_channel_email' => :'String',
    :'open_support_ticket_zoho_desk_department_id' => :'String',
    :'pause_subscription' => :'Boolean',
    :'resume_subscription' => :'Boolean',
    :'transfer_chat_to_live_agent' => :'Boolean',
    :'update_subscription_credit_card' => :'Boolean',
    :'zoho_desk_available' => :'Boolean',
    :'zoho_desk_departments' => :'Array<ConversationVirtualAgentCapabilityZohoDeskDepartment>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 274

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_custom_collections == o.access_custom_collections &&
      access_storefront_and_item == o.access_storefront_and_item &&
      cancel_subscription == o.cancel_subscription &&
      custom_collection_oids == o.custom_collection_oids &&
      custom_collections == o.custom_collections &&
      delay_subscription == o.delay_subscription &&
      generate_coupon == o.generate_coupon &&
      lookup_order_information == o.lookup_order_information &&
      lookup_subscription_information == o.lookup_subscription_information &&
      open_support_ticket == o.open_support_ticket &&
      open_support_ticket_channel == o.open_support_ticket_channel &&
      open_support_ticket_channel_email == o.open_support_ticket_channel_email &&
      open_support_ticket_zoho_desk_department_id == o.open_support_ticket_zoho_desk_department_id &&
      pause_subscription == o.pause_subscription &&
      resume_subscription == o.resume_subscription &&
      transfer_chat_to_live_agent == o.transfer_chat_to_live_agent &&
      update_subscription_credit_card == o.update_subscription_credit_card &&
      zoho_desk_available == o.zoho_desk_available &&
      zoho_desk_departments == o.zoho_desk_departments
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 344

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = UltracartClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 415

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 320

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


300
301
302
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 300

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



306
307
308
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 306

def hash
  [access_custom_collections, access_storefront_and_item, cancel_subscription, custom_collection_oids, custom_collections, delay_subscription, generate_coupon, lookup_order_information, lookup_subscription_information, open_support_ticket, open_support_ticket_channel, open_support_ticket_channel_email, open_support_ticket_zoho_desk_department_id, pause_subscription, resume_subscription, transfer_chat_to_live_agent, update_subscription_credit_card, zoho_desk_available, zoho_desk_departments].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



249
250
251
252
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 249

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



391
392
393
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 391

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 397

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



385
386
387
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 385

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



256
257
258
259
260
# File 'lib/ultracart_api/models/conversation_virtual_agent_capabilities.rb', line 256

def valid?
  open_support_ticket_channel_validator = EnumAttributeValidator.new('String', ["none", "email", "ultracart_task", "zoho_desk_ticket"])
  return false unless open_support_ticket_channel_validator.valid?(@open_support_ticket_channel)
  true
end