Class: UltracartClient::OrderFormat

Inherits:
Object
  • Object
show all
Defined in:
lib/ultracart_api/models/order_format.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OrderFormat

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/ultracart_api/models/order_format.rb', line 150

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `UltracartClient::OrderFormat` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `UltracartClient::OrderFormat`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'context')
    self.context = attributes[:'context']
  end

  if attributes.key?(:'dont_link_email_to_search')
    self.dont_link_email_to_search = attributes[:'dont_link_email_to_search']
  end

  if attributes.key?(:'email_as_link')
    self.email_as_link = attributes[:'email_as_link']
  end

  if attributes.key?(:'filter_distribution_center_oid')
    self.filter_distribution_center_oid = attributes[:'filter_distribution_center_oid']
  end

  if attributes.key?(:'filter_to_items_in_container_oid')
    self.filter_to_items_in_container_oid = attributes[:'filter_to_items_in_container_oid']
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  end

  if attributes.key?(:'hide_bill_to_address')
    self.hide_bill_to_address = attributes[:'hide_bill_to_address']
  end

  if attributes.key?(:'hide_price_information')
    self.hide_price_information = attributes[:'hide_price_information']
  end

  if attributes.key?(:'link_file_attachments')
    self.link_file_attachments = attributes[:'link_file_attachments']
  end

  if attributes.key?(:'show_contact_info')
    self.show_contact_info = attributes[:'show_contact_info']
  end

  if attributes.key?(:'show_in_merchant_currency')
    self.show_in_merchant_currency = attributes[:'show_in_merchant_currency']
  end

  if attributes.key?(:'show_internal_information')
    self.show_internal_information = attributes[:'show_internal_information']
  end

  if attributes.key?(:'show_merchant_notes')
    self.show_merchant_notes = attributes[:'show_merchant_notes']
  end

  if attributes.key?(:'show_non_sensitive_payment_info')
    self.show_non_sensitive_payment_info = attributes[:'show_non_sensitive_payment_info']
  end

  if attributes.key?(:'show_payment_info')
    self.show_payment_info = attributes[:'show_payment_info']
  end

  if attributes.key?(:'translate')
    self.translate = attributes[:'translate']
  end

  if attributes.key?(:'use_phone_number_web_component')
    self.use_phone_number_web_component = attributes[:'use_phone_number_web_component']
  end
end

Instance Attribute Details

#context ⇒ Object

The context to generate the order view for.



19
20
21
# File 'lib/ultracart_api/models/order_format.rb', line 19

def context
  @context
end

True to not link the email address to the order search



22
23
24
# File 'lib/ultracart_api/models/order_format.rb', line 22

def dont_link_email_to_search
  @dont_link_email_to_search
end

True to make the email address a clickable mailto link



25
26
27
# File 'lib/ultracart_api/models/order_format.rb', line 25

def email_as_link
  @email_as_link
end

#filter_distribution_center_oid ⇒ Object

Specify a distribution center oid to filter the items displayed to that particular distribution center.



28
29
30
# File 'lib/ultracart_api/models/order_format.rb', line 28

def filter_distribution_center_oid
  @filter_distribution_center_oid
end

#filter_to_items_in_container_oid ⇒ Object

The container oid to filter items to.



31
32
33
# File 'lib/ultracart_api/models/order_format.rb', line 31

def filter_to_items_in_container_oid
  @filter_to_items_in_container_oid
end

#format ⇒ Object

The desired format.



34
35
36
# File 'lib/ultracart_api/models/order_format.rb', line 34

def format
  @format
end

#hide_bill_to_address ⇒ Object

True to ide the bill to address



37
38
39
# File 'lib/ultracart_api/models/order_format.rb', line 37

def hide_bill_to_address
  @hide_bill_to_address
end

#hide_price_information ⇒ Object

True to hide price information



40
41
42
# File 'lib/ultracart_api/models/order_format.rb', line 40

def hide_price_information
  @hide_price_information
end

True to link file attachments for download



43
44
45
# File 'lib/ultracart_api/models/order_format.rb', line 43

def link_file_attachments
  @link_file_attachments
end

#show_contact_info ⇒ Object

True to show contact information



46
47
48
# File 'lib/ultracart_api/models/order_format.rb', line 46

def show_contact_info
  @show_contact_info
end

#show_in_merchant_currency ⇒ Object

True to show the order in the merchant currency



49
50
51
# File 'lib/ultracart_api/models/order_format.rb', line 49

def show_in_merchant_currency
  @show_in_merchant_currency
end

#show_internal_information ⇒ Object

True to show internal information about the order



52
53
54
# File 'lib/ultracart_api/models/order_format.rb', line 52

def show_internal_information
  @show_internal_information
end

#show_merchant_notes ⇒ Object

True to show merchant notes



55
56
57
# File 'lib/ultracart_api/models/order_format.rb', line 55

def show_merchant_notes
  @show_merchant_notes
end

#show_non_sensitive_payment_info ⇒ Object

True to show non-sensitive payment information



58
59
60
# File 'lib/ultracart_api/models/order_format.rb', line 58

def show_non_sensitive_payment_info
  @show_non_sensitive_payment_info
end

#show_payment_info ⇒ Object

True to show payment information



61
62
63
# File 'lib/ultracart_api/models/order_format.rb', line 61

def show_payment_info
  @show_payment_info
end

#translate ⇒ Object

True to translate the order into the native language of the customer



64
65
66
# File 'lib/ultracart_api/models/order_format.rb', line 64

def translate
  @translate
end

#use_phone_number_web_component ⇒ Object

True to render phone numbers as web components in the HTML output. Only honored by the div format. Default false preserves legacy scalar rendering for receipts and unauthenticated consumers.



67
68
69
# File 'lib/ultracart_api/models/order_format.rb', line 67

def use_phone_number_web_component
  @use_phone_number_web_component
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



115
116
117
# File 'lib/ultracart_api/models/order_format.rb', line 115

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/ultracart_api/models/order_format.rb', line 92

def self.attribute_map
  {
    :'context' => :'context',
    :'dont_link_email_to_search' => :'dont_link_email_to_search',
    :'email_as_link' => :'email_as_link',
    :'filter_distribution_center_oid' => :'filter_distribution_center_oid',
    :'filter_to_items_in_container_oid' => :'filter_to_items_in_container_oid',
    :'format' => :'format',
    :'hide_bill_to_address' => :'hide_bill_to_address',
    :'hide_price_information' => :'hide_price_information',
    :'link_file_attachments' => :'link_file_attachments',
    :'show_contact_info' => :'show_contact_info',
    :'show_in_merchant_currency' => :'show_in_merchant_currency',
    :'show_internal_information' => :'show_internal_information',
    :'show_merchant_notes' => :'show_merchant_notes',
    :'show_non_sensitive_payment_info' => :'show_non_sensitive_payment_info',
    :'show_payment_info' => :'show_payment_info',
    :'translate' => :'translate',
    :'use_phone_number_web_component' => :'use_phone_number_web_component'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



296
297
298
# File 'lib/ultracart_api/models/order_format.rb', line 296

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



143
144
145
146
# File 'lib/ultracart_api/models/order_format.rb', line 143

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/ultracart_api/models/order_format.rb', line 120

def self.openapi_types
  {
    :'context' => :'String',
    :'dont_link_email_to_search' => :'Boolean',
    :'email_as_link' => :'Boolean',
    :'filter_distribution_center_oid' => :'Integer',
    :'filter_to_items_in_container_oid' => :'Integer',
    :'format' => :'String',
    :'hide_bill_to_address' => :'Boolean',
    :'hide_price_information' => :'Boolean',
    :'link_file_attachments' => :'Boolean',
    :'show_contact_info' => :'Boolean',
    :'show_in_merchant_currency' => :'Boolean',
    :'show_internal_information' => :'Boolean',
    :'show_merchant_notes' => :'Boolean',
    :'show_non_sensitive_payment_info' => :'Boolean',
    :'show_payment_info' => :'Boolean',
    :'translate' => :'Boolean',
    :'use_phone_number_web_component' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/ultracart_api/models/order_format.rb', line 259

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      context == o.context &&
      dont_link_email_to_search == o.dont_link_email_to_search &&
      email_as_link == o.email_as_link &&
      filter_distribution_center_oid == o.filter_distribution_center_oid &&
      filter_to_items_in_container_oid == o.filter_to_items_in_container_oid &&
      format == o.format &&
      hide_bill_to_address == o.hide_bill_to_address &&
      hide_price_information == o.hide_price_information &&
      link_file_attachments == o.link_file_attachments &&
      show_contact_info == o.show_contact_info &&
      show_in_merchant_currency == o.show_in_merchant_currency &&
      show_internal_information == o.show_internal_information &&
      show_merchant_notes == o.show_merchant_notes &&
      show_non_sensitive_payment_info == o.show_non_sensitive_payment_info &&
      show_payment_info == o.show_payment_info &&
      translate == o.translate &&
      use_phone_number_web_component == o.use_phone_number_web_component
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/ultracart_api/models/order_format.rb', line 327

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = UltracartClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/ultracart_api/models/order_format.rb', line 398

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/ultracart_api/models/order_format.rb', line 303

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


283
284
285
# File 'lib/ultracart_api/models/order_format.rb', line 283

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



289
290
291
# File 'lib/ultracart_api/models/order_format.rb', line 289

def hash
  [context, dont_link_email_to_search, email_as_link, filter_distribution_center_oid, filter_to_items_in_container_oid, format, hide_bill_to_address, hide_price_information, link_file_attachments, show_contact_info, show_in_merchant_currency, show_internal_information, show_merchant_notes, show_non_sensitive_payment_info, show_payment_info, translate, use_phone_number_web_component].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



234
235
236
237
# File 'lib/ultracart_api/models/order_format.rb', line 234

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



374
375
376
# File 'lib/ultracart_api/models/order_format.rb', line 374

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/ultracart_api/models/order_format.rb', line 380

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



368
369
370
# File 'lib/ultracart_api/models/order_format.rb', line 368

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



241
242
243
244
245
# File 'lib/ultracart_api/models/order_format.rb', line 241

def valid?
  format_validator = EnumAttributeValidator.new('String', ["text", "div", "table", "email"])
  return false unless format_validator.valid?(@format)
  true
end