Class: UltracartClient::PointOfSaleLocation

Inherits:
Object
  • Object
show all
Defined in:
lib/ultracart_api/models/point_of_sale_location.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PointOfSaleLocation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `UltracartClient::PointOfSaleLocation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `UltracartClient::PointOfSaleLocation`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'adddress2')
    self.adddress2 = attributes[:'adddress2']
  end

  if attributes.key?(:'address1')
    self.address1 = attributes[:'address1']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'distribution_center_code')
    self.distribution_center_code = attributes[:'distribution_center_code']
  end

  if attributes.key?(:'external_id')
    self.external_id = attributes[:'external_id']
  end

  if attributes.key?(:'merchant_id')
    self.merchant_id = attributes[:'merchant_id']
  end

  if attributes.key?(:'pos_location_oid')
    self.pos_location_oid = attributes[:'pos_location_oid']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'state_province')
    self.state_province = attributes[:'state_province']
  end

  if attributes.key?(:'tax_county')
    self.tax_county = attributes[:'tax_county']
  end
end

Instance Attribute Details

#adddress2 ⇒ Object

Address line 2



19
20
21
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 19

def adddress2
  @adddress2
end

#address1 ⇒ Object

Address line 1



22
23
24
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 22

def address1
  @address1
end

#city ⇒ Object

City



25
26
27
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 25

def city
  @city
end

#country ⇒ Object

Country



28
29
30
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 28

def country
  @country
end

#distribution_center_code ⇒ Object

The distribution center code where inventory is reduced from for this sale.



31
32
33
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 31

def distribution_center_code
  @distribution_center_code
end

#external_id ⇒ Object

External Id useful for syncing with a remote filesystem, this may be an MD5 hash or whatever suits your needs.



34
35
36
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 34

def external_id
  @external_id
end

#merchant_id ⇒ Object

Merchant ID that owns this location



37
38
39
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 37

def merchant_id
  @merchant_id
end

#pos_location_oid ⇒ Object

Object identifier of the point of sale location.



40
41
42
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 40

def pos_location_oid
  @pos_location_oid
end

#postal_code ⇒ Object

Postal code



43
44
45
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 43

def postal_code
  @postal_code
end

#state_province ⇒ Object

State/province



46
47
48
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 46

def state_province
  @state_province
end

#tax_county ⇒ Object

Tax county associated with this address. Need when a self managed tax configuration is being used.



49
50
51
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 49

def tax_county
  @tax_county
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 69

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 52

def self.attribute_map
  {
    :'adddress2' => :'adddress2',
    :'address1' => :'address1',
    :'city' => :'city',
    :'country' => :'country',
    :'distribution_center_code' => :'distribution_center_code',
    :'external_id' => :'external_id',
    :'merchant_id' => :'merchant_id',
    :'pos_location_oid' => :'pos_location_oid',
    :'postal_code' => :'postal_code',
    :'state_province' => :'state_province',
    :'tax_county' => :'tax_county'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



232
233
234
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 232

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



91
92
93
94
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 74

def self.openapi_types
  {
    :'adddress2' => :'String',
    :'address1' => :'String',
    :'city' => :'String',
    :'country' => :'String',
    :'distribution_center_code' => :'String',
    :'external_id' => :'String',
    :'merchant_id' => :'String',
    :'pos_location_oid' => :'Integer',
    :'postal_code' => :'String',
    :'state_province' => :'String',
    :'tax_county' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 201

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      adddress2 == o.adddress2 &&
      address1 == o.address1 &&
      city == o.city &&
      country == o.country &&
      distribution_center_code == o.distribution_center_code &&
      external_id == o.external_id &&
      merchant_id == o.merchant_id &&
      pos_location_oid == o.pos_location_oid &&
      postal_code == o.postal_code &&
      state_province == o.state_province &&
      tax_county == o.tax_county
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 263

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = UltracartClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 334

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 239

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


219
220
221
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 219

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



225
226
227
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 225

def hash
  [adddress2, address1, city, country, distribution_center_code, external_id, merchant_id, pos_location_oid, postal_code, state_province, tax_county].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 158

def list_invalid_properties
  invalid_properties = Array.new
  if !@external_id.nil? && @external_id.to_s.length > 100
    invalid_properties.push('invalid value for "external_id", the character length must be smaller than or equal to 100.')
  end

  if !@tax_county.nil? && @tax_county.to_s.length > 32
    invalid_properties.push('invalid value for "tax_county", the character length must be smaller than or equal to 32.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



310
311
312
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 310

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 316

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



304
305
306
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 304

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



173
174
175
176
177
# File 'lib/ultracart_api/models/point_of_sale_location.rb', line 173

def valid?
  return false if !@external_id.nil? && @external_id.to_s.length > 100
  return false if !@tax_county.nil? && @tax_county.to_s.length > 32
  true
end