Class: UltracartClient::SfvbLibraryEntry

Inherits:
Object
  • Object
show all
Defined in:
lib/ultracart_api/models/sfvb_library_entry.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SfvbLibraryEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `UltracartClient::SfvbLibraryEntry` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `UltracartClient::SfvbLibraryEntry`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'bookmarked')
    self.bookmarked = attributes[:'bookmarked']
  end

  if attributes.key?(:'cjson')
    self.cjson = attributes[:'cjson']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'library_oid')
    self.library_oid = attributes[:'library_oid']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'owned')
    self.owned = attributes[:'owned']
  end

  if attributes.key?(:'referenced_files')
    if (value = attributes[:'referenced_files']).is_a?(Array)
      self.referenced_files = value
    end
  end

  if attributes.key?(:'screenshot_key')
    self.screenshot_key = attributes[:'screenshot_key']
  end

  if attributes.key?(:'share_with_account')
    self. = attributes[:'share_with_account']
  end

  if attributes.key?(:'thumbnail_key')
    self.thumbnail_key = attributes[:'thumbnail_key']
  end

  if attributes.key?(:'widget_type')
    self.widget_type = attributes[:'widget_type']
  end
end

Instance Attribute Details

#bookmarked ⇒ Object

True when the calling user has bookmarked this entry.



19
20
21
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 19

def bookmarked
  @bookmarked
end

#cjson ⇒ Object

The fragment's CJSON. Omitted from search results to keep them terse; fetch a single entry to get it.



22
23
24
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 22

def cjson
  @cjson
end

#description ⇒ Object

What this fragment is for.



25
26
27
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 25

def description
  @description
end

#library_oid ⇒ Object

Library entry oid.



28
29
30
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 28

def library_oid
  @library_oid
end

#name ⇒ Object

Entry name.



31
32
33
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 31

def name
  @name
end

#owned ⇒ Object

True when the calling user owns this entry.



34
35
36
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 34

def owned
  @owned
end

#referenced_files ⇒ Object

Storefront file paths this fragment references. Installing the fragment copies them into the storefront; reading it does not.



37
38
39
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 37

def referenced_files
  @referenced_files
end

#screenshot_key ⇒ Object

S3 listing key for the large screenshot, when one has been generated.



40
41
42
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 40

def screenshot_key
  @screenshot_key
end

#share_with_account ⇒ Object

True when the entry is shared across the merchant account.



43
44
45
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 43

def 
  @share_with_account
end

#thumbnail_key ⇒ Object

S3 listing key for the medium thumbnail, when one has been generated. Thumbnails are produced asynchronously and can lag a save by a minute or two.



46
47
48
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 46

def thumbnail_key
  @thumbnail_key
end

#widget_type ⇒ Object

Element type at the root of the fragment.



49
50
51
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 49

def widget_type
  @widget_type
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 69

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 52

def self.attribute_map
  {
    :'bookmarked' => :'bookmarked',
    :'cjson' => :'cjson',
    :'description' => :'description',
    :'library_oid' => :'library_oid',
    :'name' => :'name',
    :'owned' => :'owned',
    :'referenced_files' => :'referenced_files',
    :'screenshot_key' => :'screenshot_key',
    :'share_with_account' => :'share_with_account',
    :'thumbnail_key' => :'thumbnail_key',
    :'widget_type' => :'widget_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



204
205
206
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 204

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



91
92
93
94
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 74

def self.openapi_types
  {
    :'bookmarked' => :'Boolean',
    :'cjson' => :'String',
    :'description' => :'String',
    :'library_oid' => :'Integer',
    :'name' => :'String',
    :'owned' => :'Boolean',
    :'referenced_files' => :'Array<String>',
    :'screenshot_key' => :'String',
    :'share_with_account' => :'Boolean',
    :'thumbnail_key' => :'String',
    :'widget_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      bookmarked == o.bookmarked &&
      cjson == o.cjson &&
      description == o.description &&
      library_oid == o.library_oid &&
      name == o.name &&
      owned == o.owned &&
      referenced_files == o.referenced_files &&
      screenshot_key == o.screenshot_key &&
       == o. &&
      thumbnail_key == o.thumbnail_key &&
      widget_type == o.widget_type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 235

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = UltracartClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 306

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 211

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


191
192
193
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 191

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



197
198
199
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 197

def hash
  [bookmarked, cjson, description, library_oid, name, owned, referenced_files, screenshot_key, , thumbnail_key, widget_type].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



160
161
162
163
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 160

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



282
283
284
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 282

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 288

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



276
277
278
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 276

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



167
168
169
# File 'lib/ultracart_api/models/sfvb_library_entry.rb', line 167

def valid?
  true
end