Class: UltracartClient::Webhook
- Inherits:
-
Object
- Object
- UltracartClient::Webhook
- Defined in:
- lib/ultracart_api/models/webhook.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#api_user_oid ⇒ Object
Populated if webhook associated with an API user.
-
#api_version ⇒ Object
Version of the API objects that are sent in notifications.
-
#application_profile ⇒ Object
Returns the value of attribute application_profile.
-
#authentication_type ⇒ Object
The type of authentication this webhook will use when communicating with your server.
-
#basic_password ⇒ Object
Basic authentication password.
-
#basic_username ⇒ Object
Basic authentication user name.
-
#compress_events ⇒ Object
Compress events with GZIP then base 64 encode them as a string.
-
#consecutive_failures ⇒ Object
The number of consecutive failures that have occurred trying to deliver notifications to the target server.
-
#disabled ⇒ Object
True if the webhook has been disabled.
-
#event_categories ⇒ Object
The categories of events.
-
#iam_access_key ⇒ Object
IAM Access Key for AWS SQS Delivery.
-
#iam_secret_key ⇒ Object
IAM Secret Key for AWS SQS Delivery.
-
#maximum_events ⇒ Object
The maximum number of events in the payload that UltraCart will deliver.
-
#maximum_size ⇒ Object
The maximum size of the payload that UltraCart will deliver.
-
#merchant_comments ⇒ Object
Merchant comments about this webhook.
-
#merchant_id ⇒ Object
The UltraCart merchant ID that owns this webhook.
-
#name ⇒ Object
Friendly name to help identify this webhook.
-
#next_retry_after ⇒ Object
The next time UltraCart will attempt delivery if failures have been occurring.
-
#pending ⇒ Object
The number of pending events for this webhook.
-
#webhook_oid ⇒ Object
The object identifier for this webhook.
-
#webhook_url ⇒ Object
The URL to deliver events to.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Webhook
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Webhook
Initializes the object
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/ultracart_api/models/webhook.rb', line 169 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `UltracartClient::Webhook` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `UltracartClient::Webhook`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'api_user_oid') self.api_user_oid = attributes[:'api_user_oid'] end if attributes.key?(:'api_version') self.api_version = attributes[:'api_version'] end if attributes.key?(:'application_profile') self.application_profile = attributes[:'application_profile'] end if attributes.key?(:'authentication_type') self.authentication_type = attributes[:'authentication_type'] end if attributes.key?(:'basic_password') self.basic_password = attributes[:'basic_password'] end if attributes.key?(:'basic_username') self.basic_username = attributes[:'basic_username'] end if attributes.key?(:'compress_events') self.compress_events = attributes[:'compress_events'] end if attributes.key?(:'consecutive_failures') self.consecutive_failures = attributes[:'consecutive_failures'] end if attributes.key?(:'disabled') self.disabled = attributes[:'disabled'] end if attributes.key?(:'event_categories') if (value = attributes[:'event_categories']).is_a?(Array) self.event_categories = value end end if attributes.key?(:'iam_access_key') self.iam_access_key = attributes[:'iam_access_key'] end if attributes.key?(:'iam_secret_key') self.iam_secret_key = attributes[:'iam_secret_key'] end if attributes.key?(:'maximum_events') self.maximum_events = attributes[:'maximum_events'] end if attributes.key?(:'maximum_size') self.maximum_size = attributes[:'maximum_size'] end if attributes.key?(:'merchant_comments') self.merchant_comments = attributes[:'merchant_comments'] end if attributes.key?(:'merchant_id') self.merchant_id = attributes[:'merchant_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'next_retry_after') self.next_retry_after = attributes[:'next_retry_after'] end if attributes.key?(:'pending') self.pending = attributes[:'pending'] end if attributes.key?(:'webhook_oid') self.webhook_oid = attributes[:'webhook_oid'] end if attributes.key?(:'webhook_url') self.webhook_url = attributes[:'webhook_url'] end end |
Instance Attribute Details
#api_user_oid ⇒ Object
Populated if webhook associated with an API user
19 20 21 |
# File 'lib/ultracart_api/models/webhook.rb', line 19 def api_user_oid @api_user_oid end |
#api_version ⇒ Object
Version of the API objects that are sent in notifications
22 23 24 |
# File 'lib/ultracart_api/models/webhook.rb', line 22 def api_version @api_version end |
#application_profile ⇒ Object
Returns the value of attribute application_profile.
24 25 26 |
# File 'lib/ultracart_api/models/webhook.rb', line 24 def application_profile @application_profile end |
#authentication_type ⇒ Object
The type of authentication this webhook will use when communicating with your server
27 28 29 |
# File 'lib/ultracart_api/models/webhook.rb', line 27 def authentication_type @authentication_type end |
#basic_password ⇒ Object
Basic authentication password
30 31 32 |
# File 'lib/ultracart_api/models/webhook.rb', line 30 def basic_password @basic_password end |
#basic_username ⇒ Object
Basic authentication user name
33 34 35 |
# File 'lib/ultracart_api/models/webhook.rb', line 33 def basic_username @basic_username end |
#compress_events ⇒ Object
Compress events with GZIP then base 64 encode them as a string
36 37 38 |
# File 'lib/ultracart_api/models/webhook.rb', line 36 def compress_events @compress_events end |
#consecutive_failures ⇒ Object
The number of consecutive failures that have occurred trying to deliver notifications to the target server
39 40 41 |
# File 'lib/ultracart_api/models/webhook.rb', line 39 def consecutive_failures @consecutive_failures end |
#disabled ⇒ Object
True if the webhook has been disabled
42 43 44 |
# File 'lib/ultracart_api/models/webhook.rb', line 42 def disabled @disabled end |
#event_categories ⇒ Object
The categories of events. Individual events and subscriptions are handled in the child objects. _placeholders parameter effects the population of this on a retrieval.
45 46 47 |
# File 'lib/ultracart_api/models/webhook.rb', line 45 def event_categories @event_categories end |
#iam_access_key ⇒ Object
IAM Access Key for AWS SQS Delivery
48 49 50 |
# File 'lib/ultracart_api/models/webhook.rb', line 48 def iam_access_key @iam_access_key end |
#iam_secret_key ⇒ Object
IAM Secret Key for AWS SQS Delivery
51 52 53 |
# File 'lib/ultracart_api/models/webhook.rb', line 51 def iam_secret_key @iam_secret_key end |
#maximum_events ⇒ Object
The maximum number of events in the payload that UltraCart will deliver
54 55 56 |
# File 'lib/ultracart_api/models/webhook.rb', line 54 def maximum_events @maximum_events end |
#maximum_size ⇒ Object
The maximum size of the payload that UltraCart will deliver
57 58 59 |
# File 'lib/ultracart_api/models/webhook.rb', line 57 def maximum_size @maximum_size end |
#merchant_comments ⇒ Object
Merchant comments about this webhook
60 61 62 |
# File 'lib/ultracart_api/models/webhook.rb', line 60 def merchant_comments @merchant_comments end |
#merchant_id ⇒ Object
The UltraCart merchant ID that owns this webhook
63 64 65 |
# File 'lib/ultracart_api/models/webhook.rb', line 63 def merchant_id @merchant_id end |
#name ⇒ Object
Friendly name to help identify this webhook
66 67 68 |
# File 'lib/ultracart_api/models/webhook.rb', line 66 def name @name end |
#next_retry_after ⇒ Object
The next time UltraCart will attempt delivery if failures have been occurring
69 70 71 |
# File 'lib/ultracart_api/models/webhook.rb', line 69 def next_retry_after @next_retry_after end |
#pending ⇒ Object
The number of pending events for this webhook
72 73 74 |
# File 'lib/ultracart_api/models/webhook.rb', line 72 def pending @pending end |
#webhook_oid ⇒ Object
The object identifier for this webhook
75 76 77 |
# File 'lib/ultracart_api/models/webhook.rb', line 75 def webhook_oid @webhook_oid end |
#webhook_url ⇒ Object
The URL to deliver events to. Must be HTTPS for customer related information.
78 79 80 |
# File 'lib/ultracart_api/models/webhook.rb', line 78 def webhook_url @webhook_url end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
130 131 132 |
# File 'lib/ultracart_api/models/webhook.rb', line 130 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/ultracart_api/models/webhook.rb', line 103 def self.attribute_map { :'api_user_oid' => :'api_user_oid', :'api_version' => :'api_version', :'application_profile' => :'application_profile', :'authentication_type' => :'authentication_type', :'basic_password' => :'basic_password', :'basic_username' => :'basic_username', :'compress_events' => :'compress_events', :'consecutive_failures' => :'consecutive_failures', :'disabled' => :'disabled', :'event_categories' => :'event_categories', :'iam_access_key' => :'iam_access_key', :'iam_secret_key' => :'iam_secret_key', :'maximum_events' => :'maximum_events', :'maximum_size' => :'maximum_size', :'merchant_comments' => :'merchant_comments', :'merchant_id' => :'merchant_id', :'name' => :'name', :'next_retry_after' => :'next_retry_after', :'pending' => :'pending', :'webhook_oid' => :'webhook_oid', :'webhook_url' => :'webhook_url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
379 380 381 |
# File 'lib/ultracart_api/models/webhook.rb', line 379 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
162 163 164 165 |
# File 'lib/ultracart_api/models/webhook.rb', line 162 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/ultracart_api/models/webhook.rb', line 135 def self.openapi_types { :'api_user_oid' => :'Integer', :'api_version' => :'String', :'application_profile' => :'ApiUserApplicationProfile', :'authentication_type' => :'String', :'basic_password' => :'String', :'basic_username' => :'String', :'compress_events' => :'Boolean', :'consecutive_failures' => :'Integer', :'disabled' => :'Boolean', :'event_categories' => :'Array<WebhookEventCategory>', :'iam_access_key' => :'String', :'iam_secret_key' => :'String', :'maximum_events' => :'Integer', :'maximum_size' => :'Integer', :'merchant_comments' => :'String', :'merchant_id' => :'String', :'name' => :'String', :'next_retry_after' => :'String', :'pending' => :'Integer', :'webhook_oid' => :'Integer', :'webhook_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/ultracart_api/models/webhook.rb', line 338 def ==(o) return true if self.equal?(o) self.class == o.class && api_user_oid == o.api_user_oid && api_version == o.api_version && application_profile == o.application_profile && authentication_type == o.authentication_type && basic_password == o.basic_password && basic_username == o.basic_username && compress_events == o.compress_events && consecutive_failures == o.consecutive_failures && disabled == o.disabled && event_categories == o.event_categories && iam_access_key == o.iam_access_key && iam_secret_key == o.iam_secret_key && maximum_events == o.maximum_events && maximum_size == o.maximum_size && merchant_comments == o.merchant_comments && merchant_id == o.merchant_id && name == o.name && next_retry_after == o.next_retry_after && pending == o.pending && webhook_oid == o.webhook_oid && webhook_url == o.webhook_url end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/ultracart_api/models/webhook.rb', line 410 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = UltracartClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/ultracart_api/models/webhook.rb', line 481 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/ultracart_api/models/webhook.rb', line 386 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
366 367 368 |
# File 'lib/ultracart_api/models/webhook.rb', line 366 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
372 373 374 |
# File 'lib/ultracart_api/models/webhook.rb', line 372 def hash [api_user_oid, api_version, application_profile, authentication_type, basic_password, basic_username, compress_events, consecutive_failures, disabled, event_categories, iam_access_key, iam_secret_key, maximum_events, maximum_size, merchant_comments, merchant_id, name, next_retry_after, pending, webhook_oid, webhook_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/ultracart_api/models/webhook.rb', line 271 def list_invalid_properties invalid_properties = Array.new if !@merchant_comments.nil? && @merchant_comments.to_s.length > 2000 invalid_properties.push('invalid value for "merchant_comments", the character length must be smaller than or equal to 2000.') end if !@name.nil? && @name.to_s.length > 80 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 80.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
457 458 459 |
# File 'lib/ultracart_api/models/webhook.rb', line 457 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
463 464 465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/ultracart_api/models/webhook.rb', line 463 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
451 452 453 |
# File 'lib/ultracart_api/models/webhook.rb', line 451 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
286 287 288 289 290 291 292 293 294 |
# File 'lib/ultracart_api/models/webhook.rb', line 286 def valid? api_version_validator = EnumAttributeValidator.new('String', ["2017-03-01"]) return false unless api_version_validator.valid?(@api_version) authentication_type_validator = EnumAttributeValidator.new('String', ["none", "basic", "api user", "aws iam"]) return false unless authentication_type_validator.valid?(@authentication_type) return false if !@merchant_comments.nil? && @merchant_comments.to_s.length > 2000 return false if !@name.nil? && @name.to_s.length > 80 true end |