Class: UltracartClient::WebhookLog
- Inherits:
-
Object
- Object
- UltracartClient::WebhookLog
- Defined in:
- lib/ultracart_api/models/webhook_log.rb
Instance Attribute Summary collapse
-
#delivery_dts ⇒ Object
Date/time of delivery.
-
#duration ⇒ Object
Number of milliseconds to process the notification.
-
#event_names ⇒ Object
Event names contained in this delivery.
-
#order_ids ⇒ Object
Order ids contained in this delivery.
-
#queue_delay ⇒ Object
Number of milliseconds of delay caused by queuing.
-
#request ⇒ Object
Request payload (first 100,000 characters).
-
#request_headers ⇒ Object
Request headers sent to the server.
-
#request_id ⇒ Object
Request id is a unique string that you can look up in the logs.
-
#response ⇒ Object
Response payload (first 100,000 characters).
-
#response_headers ⇒ Object
Response headers received from the server.
-
#status_code ⇒ Object
HTTP status code received from the server.
-
#success ⇒ Object
True if the delivery was successful.
-
#uri ⇒ Object
URI of the webhook delivered to.
-
#webhook_oid ⇒ Object
webhook oid.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookLog
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ WebhookLog
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 113 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `UltracartClient::WebhookLog` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `UltracartClient::WebhookLog`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'delivery_dts') self.delivery_dts = attributes[:'delivery_dts'] end if attributes.key?(:'duration') self.duration = attributes[:'duration'] end if attributes.key?(:'event_names') if (value = attributes[:'event_names']).is_a?(Array) self.event_names = value end end if attributes.key?(:'order_ids') if (value = attributes[:'order_ids']).is_a?(Array) self.order_ids = value end end if attributes.key?(:'queue_delay') self.queue_delay = attributes[:'queue_delay'] end if attributes.key?(:'request') self.request = attributes[:'request'] end if attributes.key?(:'request_headers') if (value = attributes[:'request_headers']).is_a?(Array) self.request_headers = value end end if attributes.key?(:'request_id') self.request_id = attributes[:'request_id'] end if attributes.key?(:'response') self.response = attributes[:'response'] end if attributes.key?(:'response_headers') if (value = attributes[:'response_headers']).is_a?(Array) self.response_headers = value end end if attributes.key?(:'status_code') self.status_code = attributes[:'status_code'] end if attributes.key?(:'success') self.success = attributes[:'success'] end if attributes.key?(:'uri') self.uri = attributes[:'uri'] end if attributes.key?(:'webhook_oid') self.webhook_oid = attributes[:'webhook_oid'] end end |
Instance Attribute Details
#delivery_dts ⇒ Object
Date/time of delivery
19 20 21 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 19 def delivery_dts @delivery_dts end |
#duration ⇒ Object
Number of milliseconds to process the notification
22 23 24 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 22 def duration @duration end |
#event_names ⇒ Object
Event names contained in this delivery
25 26 27 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 25 def event_names @event_names end |
#order_ids ⇒ Object
Order ids contained in this delivery
28 29 30 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 28 def order_ids @order_ids end |
#queue_delay ⇒ Object
Number of milliseconds of delay caused by queuing
31 32 33 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 31 def queue_delay @queue_delay end |
#request ⇒ Object
Request payload (first 100,000 characters)
34 35 36 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 34 def request @request end |
#request_headers ⇒ Object
Request headers sent to the server
37 38 39 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 37 def request_headers @request_headers end |
#request_id ⇒ Object
Request id is a unique string that you can look up in the logs
40 41 42 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 40 def request_id @request_id end |
#response ⇒ Object
Response payload (first 100,000 characters)
43 44 45 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 43 def response @response end |
#response_headers ⇒ Object
Response headers received from the server
46 47 48 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 46 def response_headers @response_headers end |
#status_code ⇒ Object
HTTP status code received from the server
49 50 51 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 49 def status_code @status_code end |
#success ⇒ Object
True if the delivery was successful
52 53 54 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 52 def success @success end |
#uri ⇒ Object
URI of the webhook delivered to
55 56 57 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 55 def uri @uri end |
#webhook_oid ⇒ Object
webhook oid
58 59 60 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 58 def webhook_oid @webhook_oid end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 81 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 61 def self.attribute_map { :'delivery_dts' => :'delivery_dts', :'duration' => :'duration', :'event_names' => :'event_names', :'order_ids' => :'order_ids', :'queue_delay' => :'queue_delay', :'request' => :'request', :'request_headers' => :'request_headers', :'request_id' => :'request_id', :'response' => :'response', :'response_headers' => :'response_headers', :'status_code' => :'status_code', :'success' => :'success', :'uri' => :'uri', :'webhook_oid' => :'webhook_oid' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 240 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
106 107 108 109 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 106 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 86 def self.openapi_types { :'delivery_dts' => :'String', :'duration' => :'Integer', :'event_names' => :'Array<String>', :'order_ids' => :'Array<String>', :'queue_delay' => :'Integer', :'request' => :'String', :'request_headers' => :'Array<HTTPHeader>', :'request_id' => :'String', :'response' => :'String', :'response_headers' => :'Array<HTTPHeader>', :'status_code' => :'Integer', :'success' => :'Boolean', :'uri' => :'String', :'webhook_oid' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 206 def ==(o) return true if self.equal?(o) self.class == o.class && delivery_dts == o.delivery_dts && duration == o.duration && event_names == o.event_names && order_ids == o.order_ids && queue_delay == o.queue_delay && request == o.request && request_headers == o.request_headers && request_id == o.request_id && response == o.response && response_headers == o.response_headers && status_code == o.status_code && success == o.success && uri == o.uri && webhook_oid == o.webhook_oid end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 271 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = UltracartClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 342 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 247 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
227 228 229 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 227 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
233 234 235 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 233 def hash [delivery_dts, duration, event_names, order_ids, queue_delay, request, request_headers, request_id, response, response_headers, status_code, success, uri, webhook_oid].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
193 194 195 196 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 193 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
318 319 320 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 318 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 324 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
312 313 314 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 312 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
200 201 202 |
# File 'lib/ultracart_api/models/webhook_log.rb', line 200 def valid? true end |