Class: UltracartClient::ConversationPbxQueue
- Inherits:
-
Object
- Object
- UltracartClient::ConversationPbxQueue
- Defined in:
- lib/ultracart_api/models/conversation_pbx_queue.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ai_priority ⇒ Object
AI Agent Priority compared to human agents.
-
#ai_summary_enabled ⇒ Object
If true, AI summaries are generated for answered calls in this queue.
-
#ai_summary_instructions ⇒ Object
Custom instructions injected into the AI summary system prompt for this queue.
-
#ai_timeout_seconds ⇒ Object
AI timeout seconds.
-
#announce_queue_position ⇒ Object
If true, the customer is told their queue position upon entering the queue.
-
#automatic_coach_agent_uuid ⇒ Object
AI Agent UUID to automatically engage to provide coaching.
-
#callback_announce_audio_uuid ⇒ Object
Custom audio file UUID for the callback offer prompt.
-
#callback_announce_say ⇒ Object
Custom TTS text for the callback offer prompt.
-
#callback_confirm_audio_uuid ⇒ Object
Custom audio file UUID for the callback confirmation message.
-
#callback_confirm_say ⇒ Object
Custom TTS text for the callback confirmation message.
-
#callback_enabled ⇒ Object
If true, the callback option is enabled for this queue.
-
#callback_hours_only ⇒ Object
When true, only offer callbacks during business hours.
-
#callback_max_attempts ⇒ Object
Maximum number of times the system will attempt to call the customer back.
-
#callback_max_offers ⇒ Object
Maximum number of times the callback option is offered to a caller per call.
-
#callback_max_pending ⇒ Object
Maximum number of pending callbacks allowed per queue.
-
#callback_offer_after_seconds ⇒ Object
Seconds a caller must wait in queue before the callback option is offered.
-
#callback_offer_interval_seconds ⇒ Object
Seconds between repeat callback offers to the same caller.
-
#callback_retry_delay_seconds ⇒ Object
Delay in seconds between callback retry attempts.
-
#context_merchant_id ⇒ Object
Optional child merchant ID this resource is assigned to.
-
#conversation_pbx_queue_uuid ⇒ Object
Conversation Pbx Queue unique identifier.
-
#conversation_voicemail_mailbox_uuid ⇒ Object
The voicemail mailbox associated with this queue.
-
#hold_conversation_pbx_audio_uuid ⇒ Object
The audio to play while holding in a queue.
-
#max_hold_seconds ⇒ Object
The maximum number of seconds for a customer to hold in a queue.
-
#members ⇒ Object
Returns the value of attribute members.
-
#merchant_id ⇒ Object
Merchant Id.
-
#name ⇒ Object
Name of queue.
-
#no_agent_available_play_audio_uuid ⇒ Object
When no agent is available after the max_hold_seconds, say this.
-
#no_agent_available_say ⇒ Object
When no agent is available after the max_hold_seconds, say this.
-
#no_agent_available_say_voice ⇒ Object
The type of voice used to say text when no agent is available.
-
#play_audio_uuid ⇒ Object
Audio played when customer enters a queue.
-
#record_call ⇒ Object
If true, any calls in this queue are recorded.
-
#say ⇒ Object
Say text when a customer enters queue.
-
#say_voice ⇒ Object
The type of voice to use when say text is spoken.
-
#twilio_taskrouter_workflow_sid ⇒ Object
Twilio taskrouter workflow sid.
-
#twilio_workspace_queue_sid ⇒ Object
Twilio workspace queue sid.
-
#voicemail ⇒ Object
If true, this queue has a voicemail associated with it.
-
#wait_critical_seconds ⇒ Object
Wait time in seconds before critical.
-
#wait_warning_seconds ⇒ Object
Wait time in seconds before warning.
-
#wrap_up_seconds ⇒ Object
Wrap up time in seconds.
-
#zoho_desk_department_id ⇒ Object
Zoho Desk department ID to create tickets in.
-
#zoho_desk_ticket_enabled ⇒ Object
If true, a Zoho Desk ticket is automatically created for answered calls in this queue.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConversationPbxQueue
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ConversationPbxQueue
Initializes the object
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 269 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `UltracartClient::ConversationPbxQueue` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `UltracartClient::ConversationPbxQueue`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ai_priority') self.ai_priority = attributes[:'ai_priority'] end if attributes.key?(:'ai_summary_enabled') self.ai_summary_enabled = attributes[:'ai_summary_enabled'] end if attributes.key?(:'ai_summary_instructions') self.ai_summary_instructions = attributes[:'ai_summary_instructions'] end if attributes.key?(:'ai_timeout_seconds') self.ai_timeout_seconds = attributes[:'ai_timeout_seconds'] end if attributes.key?(:'announce_queue_position') self.announce_queue_position = attributes[:'announce_queue_position'] end if attributes.key?(:'automatic_coach_agent_uuid') self.automatic_coach_agent_uuid = attributes[:'automatic_coach_agent_uuid'] end if attributes.key?(:'callback_announce_audio_uuid') self.callback_announce_audio_uuid = attributes[:'callback_announce_audio_uuid'] end if attributes.key?(:'callback_announce_say') self.callback_announce_say = attributes[:'callback_announce_say'] end if attributes.key?(:'callback_confirm_audio_uuid') self.callback_confirm_audio_uuid = attributes[:'callback_confirm_audio_uuid'] end if attributes.key?(:'callback_confirm_say') self.callback_confirm_say = attributes[:'callback_confirm_say'] end if attributes.key?(:'callback_enabled') self.callback_enabled = attributes[:'callback_enabled'] end if attributes.key?(:'callback_hours_only') self.callback_hours_only = attributes[:'callback_hours_only'] end if attributes.key?(:'callback_max_attempts') self.callback_max_attempts = attributes[:'callback_max_attempts'] end if attributes.key?(:'callback_max_offers') self.callback_max_offers = attributes[:'callback_max_offers'] end if attributes.key?(:'callback_max_pending') self.callback_max_pending = attributes[:'callback_max_pending'] end if attributes.key?(:'callback_offer_after_seconds') self.callback_offer_after_seconds = attributes[:'callback_offer_after_seconds'] end if attributes.key?(:'callback_offer_interval_seconds') self.callback_offer_interval_seconds = attributes[:'callback_offer_interval_seconds'] end if attributes.key?(:'callback_retry_delay_seconds') self.callback_retry_delay_seconds = attributes[:'callback_retry_delay_seconds'] end if attributes.key?(:'context_merchant_id') self.context_merchant_id = attributes[:'context_merchant_id'] end if attributes.key?(:'conversation_pbx_queue_uuid') self.conversation_pbx_queue_uuid = attributes[:'conversation_pbx_queue_uuid'] end if attributes.key?(:'conversation_voicemail_mailbox_uuid') self.conversation_voicemail_mailbox_uuid = attributes[:'conversation_voicemail_mailbox_uuid'] end if attributes.key?(:'hold_conversation_pbx_audio_uuid') self.hold_conversation_pbx_audio_uuid = attributes[:'hold_conversation_pbx_audio_uuid'] end if attributes.key?(:'max_hold_seconds') self.max_hold_seconds = attributes[:'max_hold_seconds'] end if attributes.key?(:'members') self.members = attributes[:'members'] end if attributes.key?(:'merchant_id') self.merchant_id = attributes[:'merchant_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'no_agent_available_play_audio_uuid') self.no_agent_available_play_audio_uuid = attributes[:'no_agent_available_play_audio_uuid'] end if attributes.key?(:'no_agent_available_say') self.no_agent_available_say = attributes[:'no_agent_available_say'] end if attributes.key?(:'no_agent_available_say_voice') self.no_agent_available_say_voice = attributes[:'no_agent_available_say_voice'] end if attributes.key?(:'play_audio_uuid') self.play_audio_uuid = attributes[:'play_audio_uuid'] end if attributes.key?(:'record_call') self.record_call = attributes[:'record_call'] end if attributes.key?(:'say') self.say = attributes[:'say'] end if attributes.key?(:'say_voice') self.say_voice = attributes[:'say_voice'] end if attributes.key?(:'twilio_taskrouter_workflow_sid') self.twilio_taskrouter_workflow_sid = attributes[:'twilio_taskrouter_workflow_sid'] end if attributes.key?(:'twilio_workspace_queue_sid') self.twilio_workspace_queue_sid = attributes[:'twilio_workspace_queue_sid'] end if attributes.key?(:'voicemail') self.voicemail = attributes[:'voicemail'] end if attributes.key?(:'wait_critical_seconds') self.wait_critical_seconds = attributes[:'wait_critical_seconds'] end if attributes.key?(:'wait_warning_seconds') self.wait_warning_seconds = attributes[:'wait_warning_seconds'] end if attributes.key?(:'wrap_up_seconds') self.wrap_up_seconds = attributes[:'wrap_up_seconds'] end if attributes.key?(:'zoho_desk_department_id') self.zoho_desk_department_id = attributes[:'zoho_desk_department_id'] end if attributes.key?(:'zoho_desk_ticket_enabled') self.zoho_desk_ticket_enabled = attributes[:'zoho_desk_ticket_enabled'] end end |
Instance Attribute Details
#ai_priority ⇒ Object
AI Agent Priority compared to human agents
19 20 21 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 19 def ai_priority @ai_priority end |
#ai_summary_enabled ⇒ Object
If true, AI summaries are generated for answered calls in this queue
22 23 24 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 22 def ai_summary_enabled @ai_summary_enabled end |
#ai_summary_instructions ⇒ Object
Custom instructions injected into the AI summary system prompt for this queue
25 26 27 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 25 def ai_summary_instructions @ai_summary_instructions end |
#ai_timeout_seconds ⇒ Object
AI timeout seconds
28 29 30 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 28 def ai_timeout_seconds @ai_timeout_seconds end |
#announce_queue_position ⇒ Object
If true, the customer is told their queue position upon entering the queue
31 32 33 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 31 def announce_queue_position @announce_queue_position end |
#automatic_coach_agent_uuid ⇒ Object
AI Agent UUID to automatically engage to provide coaching
34 35 36 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 34 def automatic_coach_agent_uuid @automatic_coach_agent_uuid end |
#callback_announce_audio_uuid ⇒ Object
Custom audio file UUID for the callback offer prompt
37 38 39 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 37 def callback_announce_audio_uuid @callback_announce_audio_uuid end |
#callback_announce_say ⇒ Object
Custom TTS text for the callback offer prompt
40 41 42 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 40 def callback_announce_say @callback_announce_say end |
#callback_confirm_audio_uuid ⇒ Object
Custom audio file UUID for the callback confirmation message
43 44 45 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 43 def callback_confirm_audio_uuid @callback_confirm_audio_uuid end |
#callback_confirm_say ⇒ Object
Custom TTS text for the callback confirmation message
46 47 48 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 46 def callback_confirm_say @callback_confirm_say end |
#callback_enabled ⇒ Object
If true, the callback option is enabled for this queue
49 50 51 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 49 def callback_enabled @callback_enabled end |
#callback_hours_only ⇒ Object
When true, only offer callbacks during business hours
52 53 54 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 52 def callback_hours_only @callback_hours_only end |
#callback_max_attempts ⇒ Object
Maximum number of times the system will attempt to call the customer back
55 56 57 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 55 def callback_max_attempts @callback_max_attempts end |
#callback_max_offers ⇒ Object
Maximum number of times the callback option is offered to a caller per call
58 59 60 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 58 def callback_max_offers @callback_max_offers end |
#callback_max_pending ⇒ Object
Maximum number of pending callbacks allowed per queue
61 62 63 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 61 def callback_max_pending @callback_max_pending end |
#callback_offer_after_seconds ⇒ Object
Seconds a caller must wait in queue before the callback option is offered
64 65 66 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 64 def callback_offer_after_seconds @callback_offer_after_seconds end |
#callback_offer_interval_seconds ⇒ Object
Seconds between repeat callback offers to the same caller
67 68 69 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 67 def callback_offer_interval_seconds @callback_offer_interval_seconds end |
#callback_retry_delay_seconds ⇒ Object
Delay in seconds between callback retry attempts
70 71 72 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 70 def callback_retry_delay_seconds @callback_retry_delay_seconds end |
#context_merchant_id ⇒ Object
Optional child merchant ID this resource is assigned to. Null = shared across the linked merchant group.
73 74 75 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 73 def context_merchant_id @context_merchant_id end |
#conversation_pbx_queue_uuid ⇒ Object
Conversation Pbx Queue unique identifier
76 77 78 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 76 def conversation_pbx_queue_uuid @conversation_pbx_queue_uuid end |
#conversation_voicemail_mailbox_uuid ⇒ Object
The voicemail mailbox associated with this queue
79 80 81 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 79 def conversation_voicemail_mailbox_uuid @conversation_voicemail_mailbox_uuid end |
#hold_conversation_pbx_audio_uuid ⇒ Object
The audio to play while holding in a queue
82 83 84 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 82 def hold_conversation_pbx_audio_uuid @hold_conversation_pbx_audio_uuid end |
#max_hold_seconds ⇒ Object
The maximum number of seconds for a customer to hold in a queue
85 86 87 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 85 def max_hold_seconds @max_hold_seconds end |
#members ⇒ Object
Returns the value of attribute members.
87 88 89 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 87 def members @members end |
#merchant_id ⇒ Object
Merchant Id
90 91 92 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 90 def merchant_id @merchant_id end |
#name ⇒ Object
Name of queue
93 94 95 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 93 def name @name end |
#no_agent_available_play_audio_uuid ⇒ Object
When no agent is available after the max_hold_seconds, say this
96 97 98 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 96 def no_agent_available_play_audio_uuid @no_agent_available_play_audio_uuid end |
#no_agent_available_say ⇒ Object
When no agent is available after the max_hold_seconds, say this
99 100 101 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 99 def no_agent_available_say @no_agent_available_say end |
#no_agent_available_say_voice ⇒ Object
The type of voice used to say text when no agent is available
102 103 104 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 102 def no_agent_available_say_voice @no_agent_available_say_voice end |
#play_audio_uuid ⇒ Object
Audio played when customer enters a queue
105 106 107 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 105 def play_audio_uuid @play_audio_uuid end |
#record_call ⇒ Object
If true, any calls in this queue are recorded
108 109 110 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 108 def record_call @record_call end |
#say ⇒ Object
Say text when a customer enters queue
111 112 113 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 111 def say @say end |
#say_voice ⇒ Object
The type of voice to use when say text is spoken
114 115 116 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 114 def say_voice @say_voice end |
#twilio_taskrouter_workflow_sid ⇒ Object
Twilio taskrouter workflow sid
117 118 119 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 117 def twilio_taskrouter_workflow_sid @twilio_taskrouter_workflow_sid end |
#twilio_workspace_queue_sid ⇒ Object
Twilio workspace queue sid
120 121 122 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 120 def twilio_workspace_queue_sid @twilio_workspace_queue_sid end |
#voicemail ⇒ Object
If true, this queue has a voicemail associated with it
123 124 125 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 123 def voicemail @voicemail end |
#wait_critical_seconds ⇒ Object
Wait time in seconds before critical
126 127 128 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 126 def wait_critical_seconds @wait_critical_seconds end |
#wait_warning_seconds ⇒ Object
Wait time in seconds before warning
129 130 131 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 129 def wait_warning_seconds @wait_warning_seconds end |
#wrap_up_seconds ⇒ Object
Wrap up time in seconds
132 133 134 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 132 def wrap_up_seconds @wrap_up_seconds end |
#zoho_desk_department_id ⇒ Object
Zoho Desk department ID to create tickets in
135 136 137 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 135 def zoho_desk_department_id @zoho_desk_department_id end |
#zoho_desk_ticket_enabled ⇒ Object
If true, a Zoho Desk ticket is automatically created for answered calls in this queue
138 139 140 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 138 def zoho_desk_ticket_enabled @zoho_desk_ticket_enabled end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
210 211 212 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 210 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 163 def self.attribute_map { :'ai_priority' => :'ai_priority', :'ai_summary_enabled' => :'ai_summary_enabled', :'ai_summary_instructions' => :'ai_summary_instructions', :'ai_timeout_seconds' => :'ai_timeout_seconds', :'announce_queue_position' => :'announce_queue_position', :'automatic_coach_agent_uuid' => :'automatic_coach_agent_uuid', :'callback_announce_audio_uuid' => :'callback_announce_audio_uuid', :'callback_announce_say' => :'callback_announce_say', :'callback_confirm_audio_uuid' => :'callback_confirm_audio_uuid', :'callback_confirm_say' => :'callback_confirm_say', :'callback_enabled' => :'callback_enabled', :'callback_hours_only' => :'callback_hours_only', :'callback_max_attempts' => :'callback_max_attempts', :'callback_max_offers' => :'callback_max_offers', :'callback_max_pending' => :'callback_max_pending', :'callback_offer_after_seconds' => :'callback_offer_after_seconds', :'callback_offer_interval_seconds' => :'callback_offer_interval_seconds', :'callback_retry_delay_seconds' => :'callback_retry_delay_seconds', :'context_merchant_id' => :'context_merchant_id', :'conversation_pbx_queue_uuid' => :'conversation_pbx_queue_uuid', :'conversation_voicemail_mailbox_uuid' => :'conversation_voicemail_mailbox_uuid', :'hold_conversation_pbx_audio_uuid' => :'hold_conversation_pbx_audio_uuid', :'max_hold_seconds' => :'max_hold_seconds', :'members' => :'members', :'merchant_id' => :'merchant_id', :'name' => :'name', :'no_agent_available_play_audio_uuid' => :'no_agent_available_play_audio_uuid', :'no_agent_available_say' => :'no_agent_available_say', :'no_agent_available_say_voice' => :'no_agent_available_say_voice', :'play_audio_uuid' => :'play_audio_uuid', :'record_call' => :'record_call', :'say' => :'say', :'say_voice' => :'say_voice', :'twilio_taskrouter_workflow_sid' => :'twilio_taskrouter_workflow_sid', :'twilio_workspace_queue_sid' => :'twilio_workspace_queue_sid', :'voicemail' => :'voicemail', :'wait_critical_seconds' => :'wait_critical_seconds', :'wait_warning_seconds' => :'wait_warning_seconds', :'wrap_up_seconds' => :'wrap_up_seconds', :'zoho_desk_department_id' => :'zoho_desk_department_id', :'zoho_desk_ticket_enabled' => :'zoho_desk_ticket_enabled' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
764 765 766 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 764 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
262 263 264 265 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 262 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 215 def self.openapi_types { :'ai_priority' => :'String', :'ai_summary_enabled' => :'Boolean', :'ai_summary_instructions' => :'String', :'ai_timeout_seconds' => :'Integer', :'announce_queue_position' => :'Boolean', :'automatic_coach_agent_uuid' => :'String', :'callback_announce_audio_uuid' => :'String', :'callback_announce_say' => :'String', :'callback_confirm_audio_uuid' => :'String', :'callback_confirm_say' => :'String', :'callback_enabled' => :'Boolean', :'callback_hours_only' => :'Boolean', :'callback_max_attempts' => :'Integer', :'callback_max_offers' => :'Integer', :'callback_max_pending' => :'Integer', :'callback_offer_after_seconds' => :'Integer', :'callback_offer_interval_seconds' => :'Integer', :'callback_retry_delay_seconds' => :'Integer', :'context_merchant_id' => :'String', :'conversation_pbx_queue_uuid' => :'String', :'conversation_voicemail_mailbox_uuid' => :'String', :'hold_conversation_pbx_audio_uuid' => :'String', :'max_hold_seconds' => :'Integer', :'members' => :'ConversationPbxQueueMembers', :'merchant_id' => :'String', :'name' => :'String', :'no_agent_available_play_audio_uuid' => :'String', :'no_agent_available_say' => :'String', :'no_agent_available_say_voice' => :'String', :'play_audio_uuid' => :'String', :'record_call' => :'Boolean', :'say' => :'String', :'say_voice' => :'String', :'twilio_taskrouter_workflow_sid' => :'String', :'twilio_workspace_queue_sid' => :'String', :'voicemail' => :'Boolean', :'wait_critical_seconds' => :'Integer', :'wait_warning_seconds' => :'Integer', :'wrap_up_seconds' => :'Integer', :'zoho_desk_department_id' => :'String', :'zoho_desk_ticket_enabled' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 703 def ==(o) return true if self.equal?(o) self.class == o.class && ai_priority == o.ai_priority && ai_summary_enabled == o.ai_summary_enabled && ai_summary_instructions == o.ai_summary_instructions && ai_timeout_seconds == o.ai_timeout_seconds && announce_queue_position == o.announce_queue_position && automatic_coach_agent_uuid == o.automatic_coach_agent_uuid && callback_announce_audio_uuid == o.callback_announce_audio_uuid && callback_announce_say == o.callback_announce_say && callback_confirm_audio_uuid == o.callback_confirm_audio_uuid && callback_confirm_say == o.callback_confirm_say && callback_enabled == o.callback_enabled && callback_hours_only == o.callback_hours_only && callback_max_attempts == o.callback_max_attempts && callback_max_offers == o.callback_max_offers && callback_max_pending == o.callback_max_pending && callback_offer_after_seconds == o.callback_offer_after_seconds && callback_offer_interval_seconds == o.callback_offer_interval_seconds && callback_retry_delay_seconds == o.callback_retry_delay_seconds && context_merchant_id == o.context_merchant_id && conversation_pbx_queue_uuid == o.conversation_pbx_queue_uuid && conversation_voicemail_mailbox_uuid == o.conversation_voicemail_mailbox_uuid && hold_conversation_pbx_audio_uuid == o.hold_conversation_pbx_audio_uuid && max_hold_seconds == o.max_hold_seconds && members == o.members && merchant_id == o.merchant_id && name == o.name && no_agent_available_play_audio_uuid == o.no_agent_available_play_audio_uuid && no_agent_available_say == o.no_agent_available_say && no_agent_available_say_voice == o.no_agent_available_say_voice && play_audio_uuid == o.play_audio_uuid && record_call == o.record_call && say == o.say && say_voice == o.say_voice && twilio_taskrouter_workflow_sid == o.twilio_taskrouter_workflow_sid && twilio_workspace_queue_sid == o.twilio_workspace_queue_sid && voicemail == o.voicemail && wait_critical_seconds == o.wait_critical_seconds && wait_warning_seconds == o.wait_warning_seconds && wrap_up_seconds == o.wrap_up_seconds && zoho_desk_department_id == o.zoho_desk_department_id && zoho_desk_ticket_enabled == o.zoho_desk_ticket_enabled end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 795 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = UltracartClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
866 867 868 869 870 871 872 873 874 875 876 877 878 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 866 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 771 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
751 752 753 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 751 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
757 758 759 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 757 def hash [ai_priority, ai_summary_enabled, ai_summary_instructions, ai_timeout_seconds, announce_queue_position, automatic_coach_agent_uuid, callback_announce_audio_uuid, callback_announce_say, callback_confirm_audio_uuid, callback_confirm_say, callback_enabled, callback_hours_only, callback_max_attempts, callback_max_offers, callback_max_pending, callback_offer_after_seconds, callback_offer_interval_seconds, callback_retry_delay_seconds, context_merchant_id, conversation_pbx_queue_uuid, conversation_voicemail_mailbox_uuid, hold_conversation_pbx_audio_uuid, max_hold_seconds, members, merchant_id, name, no_agent_available_play_audio_uuid, no_agent_available_say, no_agent_available_say_voice, play_audio_uuid, record_call, say, say_voice, twilio_taskrouter_workflow_sid, twilio_workspace_queue_sid, voicemail, wait_critical_seconds, wait_warning_seconds, wrap_up_seconds, zoho_desk_department_id, zoho_desk_ticket_enabled].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 449 def list_invalid_properties invalid_properties = Array.new if !@ai_summary_instructions.nil? && @ai_summary_instructions.to_s.length > 100000 invalid_properties.push('invalid value for "ai_summary_instructions", the character length must be smaller than or equal to 100000.') end if !@callback_announce_audio_uuid.nil? && @callback_announce_audio_uuid.to_s.length > 50 invalid_properties.push('invalid value for "callback_announce_audio_uuid", the character length must be smaller than or equal to 50.') end if !@callback_confirm_audio_uuid.nil? && @callback_confirm_audio_uuid.to_s.length > 50 invalid_properties.push('invalid value for "callback_confirm_audio_uuid", the character length must be smaller than or equal to 50.') end if !@context_merchant_id.nil? && @context_merchant_id.to_s.length > 20 invalid_properties.push('invalid value for "context_merchant_id", the character length must be smaller than or equal to 20.') end if !@conversation_voicemail_mailbox_uuid.nil? && @conversation_voicemail_mailbox_uuid.to_s.length > 50 invalid_properties.push('invalid value for "conversation_voicemail_mailbox_uuid", the character length must be smaller than or equal to 50.') end if !@hold_conversation_pbx_audio_uuid.nil? && @hold_conversation_pbx_audio_uuid.to_s.length > 50 invalid_properties.push('invalid value for "hold_conversation_pbx_audio_uuid", the character length must be smaller than or equal to 50.') end if !@merchant_id.nil? && @merchant_id.to_s.length > 5 invalid_properties.push('invalid value for "merchant_id", the character length must be smaller than or equal to 5.') end if !@name.nil? && @name.to_s.length > 50 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 50.') end if !@no_agent_available_play_audio_uuid.nil? && @no_agent_available_play_audio_uuid.to_s.length > 50 invalid_properties.push('invalid value for "no_agent_available_play_audio_uuid", the character length must be smaller than or equal to 50.') end if !@no_agent_available_say_voice.nil? && @no_agent_available_say_voice.to_s.length > 50 invalid_properties.push('invalid value for "no_agent_available_say_voice", the character length must be smaller than or equal to 50.') end if !@play_audio_uuid.nil? && @play_audio_uuid.to_s.length > 50 invalid_properties.push('invalid value for "play_audio_uuid", the character length must be smaller than or equal to 50.') end if !@say_voice.nil? && @say_voice.to_s.length > 50 invalid_properties.push('invalid value for "say_voice", the character length must be smaller than or equal to 50.') end if !@twilio_taskrouter_workflow_sid.nil? && @twilio_taskrouter_workflow_sid.to_s.length > 100 invalid_properties.push('invalid value for "twilio_taskrouter_workflow_sid", the character length must be smaller than or equal to 100.') end if !@twilio_workspace_queue_sid.nil? && @twilio_workspace_queue_sid.to_s.length > 50 invalid_properties.push('invalid value for "twilio_workspace_queue_sid", the character length must be smaller than or equal to 50.') end if !@zoho_desk_department_id.nil? && @zoho_desk_department_id.to_s.length > 50 invalid_properties.push('invalid value for "zoho_desk_department_id", the character length must be smaller than or equal to 50.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
842 843 844 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 842 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
848 849 850 851 852 853 854 855 856 857 858 859 860 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 848 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
836 837 838 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 836 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 |
# File 'lib/ultracart_api/models/conversation_pbx_queue.rb', line 516 def valid? ai_priority_validator = EnumAttributeValidator.new('String', ["neutral", "first", "backup"]) return false unless ai_priority_validator.valid?(@ai_priority) return false if !@ai_summary_instructions.nil? && @ai_summary_instructions.to_s.length > 100000 return false if !@callback_announce_audio_uuid.nil? && @callback_announce_audio_uuid.to_s.length > 50 return false if !@callback_confirm_audio_uuid.nil? && @callback_confirm_audio_uuid.to_s.length > 50 return false if !@context_merchant_id.nil? && @context_merchant_id.to_s.length > 20 return false if !@conversation_voicemail_mailbox_uuid.nil? && @conversation_voicemail_mailbox_uuid.to_s.length > 50 return false if !@hold_conversation_pbx_audio_uuid.nil? && @hold_conversation_pbx_audio_uuid.to_s.length > 50 return false if !@merchant_id.nil? && @merchant_id.to_s.length > 5 return false if !@name.nil? && @name.to_s.length > 50 return false if !@no_agent_available_play_audio_uuid.nil? && @no_agent_available_play_audio_uuid.to_s.length > 50 no_agent_available_say_voice_validator = EnumAttributeValidator.new('String', ["man", "woman"]) return false unless no_agent_available_say_voice_validator.valid?(@no_agent_available_say_voice) return false if !@no_agent_available_say_voice.nil? && @no_agent_available_say_voice.to_s.length > 50 return false if !@play_audio_uuid.nil? && @play_audio_uuid.to_s.length > 50 say_voice_validator = EnumAttributeValidator.new('String', ["man", "woman"]) return false unless say_voice_validator.valid?(@say_voice) return false if !@say_voice.nil? && @say_voice.to_s.length > 50 return false if !@twilio_taskrouter_workflow_sid.nil? && @twilio_taskrouter_workflow_sid.to_s.length > 100 return false if !@twilio_workspace_queue_sid.nil? && @twilio_workspace_queue_sid.to_s.length > 50 return false if !@zoho_desk_department_id.nil? && @zoho_desk_department_id.to_s.length > 50 true end |