Class: UltracartClient::OrderChannelPartner
- Inherits:
-
Object
- Object
- UltracartClient::OrderChannelPartner
- Defined in:
- lib/ultracart_api/models/order_channel_partner.rb
Instance Attribute Summary collapse
-
#arbitrary_pricing_tier_names ⇒ Object
Names of pricing tiers to price this order against, without associating a customer profile.
-
#auto_approve_purchase_order ⇒ Object
If true, any purchase order submitted is automatically approved.
-
#channel_partner_code ⇒ Object
The code of the channel partner.
-
#channel_partner_data ⇒ Object
Additional data provided by the channel partner, read-only.
-
#channel_partner_oid ⇒ Object
Channel partner object identifier, read-only and available on existing channel orders only.
-
#channel_partner_order_id ⇒ Object
The order ID assigned by the channel partner for this order.
-
#ignore_invalid_shipping_method ⇒ Object
Set to true to ignore invalid shipping method being specified.
-
#no_realtime_payment_processing ⇒ Object
Indicates this order should be placed in Account Receivable for later payment processing.
-
#skip_auto_order_setup ⇒ Object
Instructs UltraCart to skip auto order setup.
-
#skip_payment_processing ⇒ Object
Indicates this order was already paid for via a channel purchase and no payment collection should be attempted.
-
#store_completed ⇒ Object
Instructs UltraCart to skip shipping department and mark this order as fully complete.
-
#store_if_payment_declines ⇒ Object
If true, any failed payment will place the order in Accounts Receivable rather than rejecting it.
-
#treat_warnings_as_errors ⇒ Object
Any warnings are raised as errors and halt the import of the order.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrderChannelPartner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ OrderChannelPartner
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `UltracartClient::OrderChannelPartner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `UltracartClient::OrderChannelPartner`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'arbitrary_pricing_tier_names') if (value = attributes[:'arbitrary_pricing_tier_names']).is_a?(Array) self.arbitrary_pricing_tier_names = value end end if attributes.key?(:'auto_approve_purchase_order') self.auto_approve_purchase_order = attributes[:'auto_approve_purchase_order'] end if attributes.key?(:'channel_partner_code') self.channel_partner_code = attributes[:'channel_partner_code'] end if attributes.key?(:'channel_partner_data') self.channel_partner_data = attributes[:'channel_partner_data'] end if attributes.key?(:'channel_partner_oid') self.channel_partner_oid = attributes[:'channel_partner_oid'] end if attributes.key?(:'channel_partner_order_id') self.channel_partner_order_id = attributes[:'channel_partner_order_id'] end if attributes.key?(:'ignore_invalid_shipping_method') self.ignore_invalid_shipping_method = attributes[:'ignore_invalid_shipping_method'] end if attributes.key?(:'no_realtime_payment_processing') self.no_realtime_payment_processing = attributes[:'no_realtime_payment_processing'] end if attributes.key?(:'skip_auto_order_setup') self.skip_auto_order_setup = attributes[:'skip_auto_order_setup'] end if attributes.key?(:'skip_payment_processing') self.skip_payment_processing = attributes[:'skip_payment_processing'] end if attributes.key?(:'store_completed') self.store_completed = attributes[:'store_completed'] end if attributes.key?(:'store_if_payment_declines') self.store_if_payment_declines = attributes[:'store_if_payment_declines'] end if attributes.key?(:'treat_warnings_as_errors') self.treat_warnings_as_errors = attributes[:'treat_warnings_as_errors'] end end |
Instance Attribute Details
#arbitrary_pricing_tier_names ⇒ Object
Names of pricing tiers to price this order against, without associating a customer profile. An unknown tier name will fail the import. An item that also supplies arbitrary_unit_cost keeps that cost and ignores the tier. If a customer profile is attached to this order during checkout, these tiers are granted to that profile permanently. Only applicable on inserting orders.
19 20 21 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 19 def arbitrary_pricing_tier_names @arbitrary_pricing_tier_names end |
#auto_approve_purchase_order ⇒ Object
If true, any purchase order submitted is automatically approved
22 23 24 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 22 def auto_approve_purchase_order @auto_approve_purchase_order end |
#channel_partner_code ⇒ Object
The code of the channel partner
25 26 27 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 25 def channel_partner_code @channel_partner_code end |
#channel_partner_data ⇒ Object
Additional data provided by the channel partner, read-only
28 29 30 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 28 def channel_partner_data @channel_partner_data end |
#channel_partner_oid ⇒ Object
Channel partner object identifier, read-only and available on existing channel orders only.
31 32 33 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 31 def channel_partner_oid @channel_partner_oid end |
#channel_partner_order_id ⇒ Object
The order ID assigned by the channel partner for this order.
34 35 36 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 34 def channel_partner_order_id @channel_partner_order_id end |
#ignore_invalid_shipping_method ⇒ Object
Set to true to ignore invalid shipping method being specified. Only applicable on inserting orders.
37 38 39 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 37 def ignore_invalid_shipping_method @ignore_invalid_shipping_method end |
#no_realtime_payment_processing ⇒ Object
Indicates this order should be placed in Account Receivable for later payment processing
40 41 42 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 40 def no_realtime_payment_processing @no_realtime_payment_processing end |
#skip_auto_order_setup ⇒ Object
Instructs UltraCart to skip auto order setup. Only applicable on inserting orders.
43 44 45 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 43 def skip_auto_order_setup @skip_auto_order_setup end |
#skip_payment_processing ⇒ Object
Indicates this order was already paid for via a channel purchase and no payment collection should be attempted
46 47 48 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 46 def skip_payment_processing @skip_payment_processing end |
#store_completed ⇒ Object
Instructs UltraCart to skip shipping department and mark this order as fully complete. This flag defaults to true. Set this flag to false to shipped product for this order.
49 50 51 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 49 def store_completed @store_completed end |
#store_if_payment_declines ⇒ Object
If true, any failed payment will place the order in Accounts Receivable rather than rejecting it.
52 53 54 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 52 def store_if_payment_declines @store_if_payment_declines end |
#treat_warnings_as_errors ⇒ Object
Any warnings are raised as errors and halt the import of the order
55 56 57 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 55 def treat_warnings_as_errors @treat_warnings_as_errors end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 77 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 58 def self.attribute_map { :'arbitrary_pricing_tier_names' => :'arbitrary_pricing_tier_names', :'auto_approve_purchase_order' => :'auto_approve_purchase_order', :'channel_partner_code' => :'channel_partner_code', :'channel_partner_data' => :'channel_partner_data', :'channel_partner_oid' => :'channel_partner_oid', :'channel_partner_order_id' => :'channel_partner_order_id', :'ignore_invalid_shipping_method' => :'ignore_invalid_shipping_method', :'no_realtime_payment_processing' => :'no_realtime_payment_processing', :'skip_auto_order_setup' => :'skip_auto_order_setup', :'skip_payment_processing' => :'skip_payment_processing', :'store_completed' => :'store_completed', :'store_if_payment_declines' => :'store_if_payment_declines', :'treat_warnings_as_errors' => :'treat_warnings_as_errors' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
239 240 241 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 239 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 101 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 82 def self.openapi_types { :'arbitrary_pricing_tier_names' => :'Array<String>', :'auto_approve_purchase_order' => :'Boolean', :'channel_partner_code' => :'String', :'channel_partner_data' => :'String', :'channel_partner_oid' => :'Integer', :'channel_partner_order_id' => :'String', :'ignore_invalid_shipping_method' => :'Boolean', :'no_realtime_payment_processing' => :'Boolean', :'skip_auto_order_setup' => :'Boolean', :'skip_payment_processing' => :'Boolean', :'store_completed' => :'Boolean', :'store_if_payment_declines' => :'Boolean', :'treat_warnings_as_errors' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 206 def ==(o) return true if self.equal?(o) self.class == o.class && arbitrary_pricing_tier_names == o.arbitrary_pricing_tier_names && auto_approve_purchase_order == o.auto_approve_purchase_order && channel_partner_code == o.channel_partner_code && channel_partner_data == o.channel_partner_data && channel_partner_oid == o.channel_partner_oid && channel_partner_order_id == o.channel_partner_order_id && ignore_invalid_shipping_method == o.ignore_invalid_shipping_method && no_realtime_payment_processing == o.no_realtime_payment_processing && skip_auto_order_setup == o.skip_auto_order_setup && skip_payment_processing == o.skip_payment_processing && store_completed == o.store_completed && store_if_payment_declines == o.store_if_payment_declines && treat_warnings_as_errors == o.treat_warnings_as_errors end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 270 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = UltracartClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 341 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 246 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
226 227 228 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 226 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
232 233 234 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 232 def hash [arbitrary_pricing_tier_names, auto_approve_purchase_order, channel_partner_code, channel_partner_data, channel_partner_oid, channel_partner_order_id, ignore_invalid_shipping_method, no_realtime_payment_processing, skip_auto_order_setup, skip_payment_processing, store_completed, store_if_payment_declines, treat_warnings_as_errors].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
178 179 180 181 182 183 184 185 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 178 def list_invalid_properties invalid_properties = Array.new if !@channel_partner_order_id.nil? && @channel_partner_order_id.to_s.length > 50 invalid_properties.push('invalid value for "channel_partner_order_id", the character length must be smaller than or equal to 50.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
317 318 319 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 317 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 323 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
311 312 313 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 311 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
189 190 191 192 |
# File 'lib/ultracart_api/models/order_channel_partner.rb', line 189 def valid? return false if !@channel_partner_order_id.nil? && @channel_partner_order_id.to_s.length > 50 true end |